@@ -1,11 +1,10 @@
-VGGFR<-function (L1, L2 = NULL, add = FALSE, lwd = 2, lty = 5, col = "blue", np = 201) {
-	cat(L1,L2,"\n")
+VGGFR<-function (L1, L2 = NULL, add = FALSE, lwd = 2, lty = 5, col = "blue", ylim=c(0,1.0), Main="", np = 201) {
 	if (is.null(L2)){L2<-L1[2];L1<-L1[1]}  
 	if (!is.numeric(L1) | !is.numeric(L2)) {stop("Non-numeric argument to mathematical function")}
 	if (!(L1>0) | !(L2>0)) {stop("Shape parameters must be positive")}
 	x<-NULL
     Vian <- function(x, L1, L2) {L1 * (1 - abs(x)^L1)^L2/(2 * beta(1/L1, 1 + L2))}
-    curve(Vian(x, L1, L2), -1, 1, np, col = col, lwd = lwd, add = add,ylab="VGGFR density")
+    curve(Vian(x, L1, L2), -1, 1, np, col = col, lwd = lwd, add = add, xlab="Domain of the random variable", ylab="Probability density", ylim=ylim, main=Main)
     Ws1 <- beta(3/L1, L2 + 1)
     Ws2 <- beta(1/L1, L2 + 1)
     Ws3 <- beta(5/L1, L2 + 1)
